@@ -1,13 +1,13 @@
 #' Robust Mahalanobis 
 #' 
-#' Compute Mahalanobis distances using the robust 
+#' Obtain Mahalanobis distances using the robust 
 #' computing methods found in the \code{MASS} package.
 #' 
 #' 
 #' @aliases robustMD 
 #' @param data matrix or data.frame 
 #' @param method type of estimation for robust means and covariance
-#' (see \code{\link{cov.rob}}
+#' (see \code{\link{cov.rob}})
 #' @param na.rm logical; remove cases with missing data?
 #' @param digits number of digits to round in the final result
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
@@ -22,12 +22,15 @@
 #' output <- robustMD(holzinger)
 #' output
 #' summary(output)
+#' plot(output)
+#' plot(output, type = 'qqplot')
 #' }
 robustMD <- function(data, method = 'mve', na.rm = TRUE, digits = 5)
 {	
 	ret <- list()
-	if(na.rm) data <- na.omit(data)	
 	id <- 1:nrow(data)
+	rownames(data) <- id
+	if(na.rm) data <- na.omit(data)		
 	rob <- cov.rob(data, method = method)	
 	ret$ID <- id
 	ret$mah <- mahalanobis(data, rob$center, rob$cov)
@@ -48,7 +51,7 @@ robustMD <- function(data, method = 'mve', na.rm = TRUE, digits = 5)
 #' @param ... additional parameters to be passed 
 print.robmah <- function(x, ...)
 {
-	print(x$mah)
+	return(print(x$mah))	
 }
 
 #' @S3method summary robmah
@@ -77,15 +80,23 @@ summary.robmah <- function(object, gt = 0, ...)
 
 #' @S3method plot robmah
 #' @param y empty parameter passed to \code{plot}
+#' @param type type of plot to display, can be either \code{'qqplot'} or \code{'xyplot'}
 #' @rdname robustMD
 #' @method plot robmah 
-plot.robmah <- function(x, y = NULL, ...){
+plot.robmah <- function(x, y = NULL, type = 'xyplot', ...){
 	mah <- x$mah
 	N <- length(mah)
 	J <- x$J
-	qqplot(qchisq(ppoints(N),df=J), mah,
-		main="QQ Plot",
-		ylab="Robust Mahalanobis Distance",
-		xlab='Theoretical Quartile')
-	abline(a=0,b=1)
+    if(type == 'qqplot'){
+        dat <- data.frame(theoryQQ = qchisq(ppoints(N),df=J), mah=mah)
+        qqmath(~mah, data=dat, prepanel = prepanel.qqmathline, main = 'QQ plot',
+               panel = function(x, ...) {
+                   panel.qqmathline(x, ...)
+                   panel.qqmath(x, ...)
+               })   	
+    }
+    if(type == 'xyplot'){
+        dat <- data.frame(mah=mah, ID=x$ID)
+        xyplot(mah~ID, dat, main="Robust MD", type = c('p', 'h'), ...)
+    }	
 }
